@@ -182,7 +182,7 @@ genericize_expected_output() {
         sed -i '/^Certificate or key are missing, generating them using update-secureboot-policy...$/d' ${output_log}
         sed -i '/^Certificate or key are missing, generating self signed certificate for MOK...$/d' ${output_log}
     else
-        sed -i "/^The kernel is be built without module signing facility, modules won't be signed$/d" ${output_log}
+        sed -i "/^The kernel is built without module signing facility, modules won't be signed$/d" ${output_log}
         sed -i "/^Binary .* not found, modules won't be signed$/d" ${output_log}
         # Uncomment the following line to run this script with --no-signing-tool on platforms where the sign-file tool exists
         # sed -i '/^Signing module \/var\/lib\/dkms\/dkms_test\/1.0\/build\/dkms_test.ko$/d' ${output_log}
@@ -678,7 +678,7 @@ echo "Running dkms autoinstall for a kernel without headers installed (expected
 run_with_expected_error 11 dkms autoinstall -k "${KERNEL_VER}-noheaders" << EOF
 Error! Your kernel headers for kernel ${KERNEL_VER}-noheaders cannot be found at /lib/modules/${KERNEL_VER}-noheaders/build or /lib/modules/${KERNEL_VER}-noheaders/source.
 Please install the linux-headers-${KERNEL_VER}-noheaders package or use the --kernelsourcedir option to tell DKMS where it's located.
-dkms autoinstall on ${KERNEL_VER}-noheaders/x86_64 failed for dkms_test(1)
+dkms autoinstall on ${KERNEL_VER}-noheaders/${KERNEL_ARCH} failed for dkms_test(1)
 Error! One or more modules failed to install during autoinstall.
 Refer to previous errors for more information.
 EOF
